@@ -27,19 +27,26 @@ class MasterFactory:
             config_defaults = salt.config.DEFAULT_MASTER_OPTS.copy()
             config_defaults.pop("user", None)
 
-        conf_dir = root_dir.join("conf").ensure(dir=True)
-        conf_file = conf_dir.join("master").strpath
-        state_tree_root = root_dir.join("state-tree").ensure(dir=True)
-        state_tree_root_base = state_tree_root.join("base").ensure(dir=True).strpath
-        state_tree_root_prod = state_tree_root.join("prod").ensure(dir=True).strpath
-        pillar_tree_root = root_dir.join("pillar-tree").ensure(dir=True)
-        pillar_tree_root_base = pillar_tree_root.join("base").ensure(dir=True).strpath
-        pillar_tree_root_prod = pillar_tree_root.join("prod").ensure(dir=True).strpath
+        conf_dir = root_dir / "conf"
+        conf_dir.mkdir(parents=True, exist_ok=True)
+        conf_file = str(conf_dir / "master")
+        state_tree_root = root_dir / "state-tree"
+        state_tree_root.mkdir(exist_ok=True)
+        state_tree_root_base = state_tree_root / "base"
+        state_tree_root_base.mkdir(exist_ok=True)
+        state_tree_root_prod = state_tree_root / "prod"
+        state_tree_root_prod.mkdir(exist_ok=True)
+        pillar_tree_root = root_dir / "pillar-tree"
+        pillar_tree_root.mkdir(exist_ok=True)
+        pillar_tree_root_base = pillar_tree_root / "base"
+        pillar_tree_root_base.mkdir(exist_ok=True)
+        pillar_tree_root_prod = pillar_tree_root / "prod"
+        pillar_tree_root_prod.mkdir(exist_ok=True)
 
         _config_defaults = {
             "id": master_id,
             "conf_file": conf_file,
-            "root_dir": root_dir.strpath,
+            "root_dir": str(root_dir),
             "interface": "127.0.0.1",
             "publish_port": ports.get_unused_localhost_port(),
             "ret_port": ports.get_unused_localhost_port(),
@@ -61,12 +68,15 @@ class MasterFactory:
             "log_level_logfile": "debug",
             "key_logfile": "logs/key.log",
             "token_dir": "tokens",
-            "token_file": root_dir.join("ksfjhdgiuebfgnkefvsikhfjdgvkjahcsidk").strpath,
+            "token_file": str(root_dir / "ksfjhdgiuebfgnkefvsikhfjdgvkjahcsidk"),
             "file_buffer_size": 8192,
             "log_fmt_console": "%(asctime)s,%(msecs)03.0f [%(name)-17s:%(lineno)-4d][%(levelname)-8s][%(processName)18s(%(process)d)] %(message)s",
             "log_fmt_logfile": "[%(asctime)s,%(msecs)03.0f][%(name)-17s:%(lineno)-4d][%(levelname)-8s][%(processName)18s(%(process)d)] %(message)s",
-            "file_roots": {"base": state_tree_root_base, "prod": state_tree_root_prod},
-            "pillar_roots": {"base": pillar_tree_root_base, "prod": pillar_tree_root_prod},
+            "file_roots": {"base": str(state_tree_root_base), "prod": str(state_tree_root_prod)},
+            "pillar_roots": {
+                "base": str(pillar_tree_root_base),
+                "prod": str(pillar_tree_root_prod),
+            },
             "hash_type": "sha256",
             "transport": "zeromq",
             "order_masters": order_masters,
