@@ -1,12 +1,12 @@
-# -*- coding: utf-8 -*-
 """
     saltfactories.plugins.markers
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     Salt Factories Related Markers
 """
+import os
+
 import pytest
-import six
 
 import saltfactories.utils.compat
 import saltfactories.utils.markers
@@ -71,7 +71,7 @@ def pytest_runtest_setup(item):
         item, "__skip_if_binaries_missing__"
     ):
         binaries = skip_if_binaries_missing_marker.args
-        if len(binaries) == 1 and not isinstance(binaries[0], six.string_types):
+        if len(binaries) == 1 and not isinstance(binaries[0], str):
             raise RuntimeError(
                 "Do not pass a list as binaries to the skip_if_binaries_missing() marker. "
                 "Instead, pass each binary as an argument to skip_if_binaries_missing()."
@@ -524,3 +524,8 @@ def pytest_configure(config):
         "netbsd=False, openbsd=False, aix=False): Pass True to one or more platform names to get the test skipped "
         "unless the chosen platforms match",
     )
+
+    # Add keys to environ in order to support Salt's helper decorators while it does not migrate to pytest markers
+    env2cli = (("DESTRUCTIVE_TESTS", "--run-destructive"), ("EXPENSIVE_TESTS", "--run-expensive"))
+    for envkey, cliflag in env2cli:
+        os.environ[str(envkey)] = str(config.getoption(cliflag)).lower()
