@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     saltfactories.utils.processes.bases
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -14,12 +13,12 @@ import subprocess
 import sys
 import tempfile
 import time
+import weakref
 from collections import namedtuple
 from operator import itemgetter
 
 import psutil
 import pytest
-import six
 
 try:
     import salt.utils.path
@@ -29,7 +28,6 @@ except ImportError:  # pragma: no cover
     # import error, but its safe to pass
     pass
 
-from saltfactories.utils import compat
 from saltfactories.utils.processes.helpers import terminate_process
 from saltfactories.exceptions import ProcessTimeout
 
@@ -49,19 +47,14 @@ class Popen(subprocess.Popen):
         kwargs["stdout"] = stdout
         stderr = tempfile.SpooledTemporaryFile(512000)
         kwargs["stderr"] = stderr
-        super(Popen, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.__stdout = stdout
         self.__stderr = stderr
-        compat.weakref.finalize(self, stdout.close)
-        compat.weakref.finalize(self, stderr.close)
-        if six.PY2:
-            # Under Py2, subprocess.Popen doesn't store the command line passed under
-            # it's args attribute.
-            # Let's do it ourselves
-            self.args = args[0]
+        weakref.finalize(self, stdout.close)
+        weakref.finalize(self, stderr.close)
 
     def communicate(self, input=None):  # pylint: disable=arguments-differ
-        super(Popen, self).communicate(input)
+        super().communicate(input)
         stdout = stderr = None
         if self.__stdout:
             self.__stdout.flush()
@@ -95,7 +88,7 @@ class ProcessResult(namedtuple("ProcessResult", ("exitcode", "stdout", "stderr",
     def __new__(cls, exitcode, stdout, stderr, cmdline=None):
         if not isinstance(exitcode, int):
             raise ValueError("'exitcode' needs to be an integer, not '{}'".format(type(exitcode)))
-        return super(ProcessResult, cls).__new__(cls, exitcode, stdout, stderr, cmdline=cmdline)
+        return super().__new__(cls, exitcode, stdout, stderr, cmdline=cmdline)
 
     # These are copied from the namedtuple verbose output in order to quiet down PyLint
     exitcode = property(itemgetter(0), doc="ProcessResult exit code property")
@@ -129,9 +122,7 @@ class ShellResult(namedtuple("ShellResult", ("exitcode", "stdout", "stderr", "js
     def __new__(cls, exitcode, stdout, stderr, json=None, cmdline=None):
         if not isinstance(exitcode, int):
             raise ValueError("'exitcode' needs to be an integer, not '{}'".format(type(exitcode)))
-        return super(ShellResult, cls).__new__(
-            cls, exitcode, stdout, stderr, json=json, cmdline=cmdline
-        )
+        return super().__new__(cls, exitcode, stdout, stderr, json=json, cmdline=cmdline)
 
     # These are copied from the namedtuple verbose output in order to quiet down PyLint
     exitcode = property(itemgetter(0), doc="ShellResult exit code property")
@@ -166,7 +157,7 @@ class ShellResult(namedtuple("ShellResult", ("exitcode", "stdout", "stderr", "js
         return self.stdout == other
 
 
-class FactoryProcess(object):
+class FactoryProcess:
     """
     Base class for subprocesses
     """
@@ -348,12 +339,12 @@ class FactoryScriptBase(FactoryProcess):
                 The maximum ammount of seconds that a script should run
         """
         default_timeout = kwargs.pop("default_timeout", None)
-        super(FactoryScriptBase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if default_timeout is None:
-            if not sys.platform.startswith("win"):
+            if not sys.platform.startswith(("win", "darwin")):
                 default_timeout = 30
             else:
-                # Windows is just slower.
+                # Windows and macOS are just slower.
                 default_timeout = 120
         self.default_timeout = default_timeout
         self._terminal_timeout_set_explicitly = False
@@ -438,15 +429,15 @@ class FactoryPythonScriptBase(FactoryScriptBase):
                 The path to the python executable to use
         """
         python_executable = kwargs.pop("python_executable", None)
-        super(FactoryPythonScriptBase, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.python_executable = python_executable or sys.executable
         # We really do not want buffered output
-        self.environ.setdefault(str("PYTHONUNBUFFERED"), str("1"))
+        self.environ.setdefault("PYTHONUNBUFFERED", "1")
         # Don't write .pyc files or create them in __pycache__ directories
-        self.environ.setdefault(str("PYTHONDONTWRITEBYTECODE"), str("1"))
+        self.environ.setdefault("PYTHONDONTWRITEBYTECODE", "1")
 
     def build_cmdline(self, *args, **kwargs):
-        cmdline = super(FactoryPythonScriptBase, self).build_cmdline(*args, **kwargs)
+        cmdline = super().build_cmdline(*args, **kwargs)
         if cmdline[0] != self.python_executable:
             cmdline.insert(0, self.python_executable)
         return cmdline
