@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 saltfactories.utils.processes.helpers
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -14,7 +13,6 @@ import time
 import weakref
 
 import psutil
-import six
 
 from saltfactories.exceptions import ProcessNotStarted
 from saltfactories.utils import ports
@@ -64,6 +62,29 @@ def _get_cmdline(proc):
             #     ret = cext.proc_cmdline(self.pid, use_peb=True)
             #   OSError: [WinError 299] Only part of a ReadProcessMemory or WriteProcessMemory request was completed: 'originated from ReadProcessMemory(ProcessParameters)
             cmdline = None
+        except RuntimeError:
+            # Also on windows
+            # saltfactories\utils\processes\helpers.py:68: in _get_cmdline
+            #     cmdline = proc.as_dict()
+            # c: ... \lib\site-packages\psutil\__init__.py:634: in as_dict
+            #     ret = meth()
+            # c: ... \lib\site-packages\psutil\__init__.py:1186: in memory_full_info
+            #     return self._proc.memory_full_info()
+            # c: ... \lib\site-packages\psutil\_pswindows.py:667: in wrapper
+            #     return fun(self, *args, **kwargs)
+            # _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _ _
+            #
+            # self = <psutil._pswindows.Process object at 0x0000029B7FDA5558>
+            #
+            #     @wrap_exceptions
+            #     def memory_full_info(self):
+            #         basic_mem = self.memory_info()
+            # >       uss = cext.proc_memory_uss(self.pid)
+            # E       RuntimeError: NtQueryVirtualMemory failed
+            #
+            # c: ... \lib\site-packages\psutil\_pswindows.py:806: RuntimeError
+            cmdline = None
+
         if not cmdline:
             try:
                 cmdline = proc.as_dict()
@@ -307,8 +328,12 @@ def start_daemon(
                     if attempts >= max_attempts:
                         raise ProcessNotStarted(
                             "{}The {!r} has failed to confirm running status after {} attempts, which "
-                            "took {:.2f} seconds".format(
-                                log_prefix, process, attempts, time.time() - checks_start_time
+                            "took {:.2f} seconds({:.2f} seconds each)".format(
+                                log_prefix,
+                                process,
+                                attempts,
+                                time.time() - checks_start_time,
+                                start_timeout,
                             ),
                             stdout=result.stdout,
                             stderr=result.stderr,
@@ -316,7 +341,7 @@ def start_daemon(
                         )
                     continue
             except ProcessNotStarted:
-                six.reraise(*sys.exc_info())
+                raise
             except Exception as exc:  # pylint: disable=broad-except
                 log.exception(
                     "%sException caugth on %r: %s", log_prefix, process, exc, exc_info=True
@@ -325,8 +350,13 @@ def start_daemon(
                 if attempts >= max_attempts:
                     raise ProcessNotStarted(
                         "{}The {!r} has failed to confirm running status after {} attempts and raised an "
-                        "exception: {}. Took {:.2f} seconds.".format(
-                            log_prefix, process, attempts, str(exc), time.time() - start_time
+                        "exception: {}. Took {:.2f} seconds({:.2f} seconds each attempt).".format(
+                            log_prefix,
+                            process,
+                            attempts,
+                            str(exc),
+                            time.time() - start_time,
+                            start_timeout,
                         ),
                         stdout=result.stdout,
                         stderr=result.stderr,
