@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 pytestsalt.salt.log_handlers.pytest_log_handler
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -15,7 +14,6 @@ import sys
 import threading
 import traceback
 
-import salt.ext.six as six
 import salt.utils.msgpack
 import salt.utils.stringutils
 from salt._logging.impl import LOG_LEVELS
@@ -79,7 +77,7 @@ def setup_handlers():
     sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     try:
         sock.connect((host_addr, host_port))
-    except socket.error as exc:
+    except OSError as exc:
         # Don't even bother if we can't connect
         log.warning("Cannot connect back to log server: %s", exc)
         return
@@ -115,7 +113,7 @@ class ZMQHandler(ExcInfoOnLogLevelFormatMixin, logging.Handler, NewStyleClassMix
     # reconnect the ZMQ machinery.
 
     def __init__(self, host="127.0.0.1", port=3330, log_prefix=None, level=logging.NOTSET):
-        super(ZMQHandler, self).__init__(level=level)
+        super().__init__(level=level)
         self.pid = os.getpid()
         self.push_address = "tcp://{}:{}".format(host, port)
         self.log_prefix = self._get_log_prefix(log_prefix)
@@ -213,20 +211,18 @@ class ZMQHandler(ExcInfoOnLogLevelFormatMixin, logging.Handler, NewStyleClassMix
                 "Failed to terminate ZMQHandler: {}\n{}\n".format(exc, traceback.format_exc(exc))
             )
             sys.stderr.flush()
-            six.reraise(*sys.exc_info())
+            raise
         finally:
             self.context = self.in_proxy = self.proxy_address = self.proxy_thread = None
 
     def format(self, record):
-        msg = super(ZMQHandler, self).format(record)
+        msg = super().format(record)
         if self.log_prefix:
             import salt.utils.stringutils
 
-            msg = six.text_type(
-                "[{}] {}".format(
-                    salt.utils.stringutils.to_unicode(self.log_prefix),
-                    salt.utils.stringutils.to_unicode(msg),
-                )
+            msg = "[{}] {}".format(
+                salt.utils.stringutils.to_unicode(self.log_prefix),
+                salt.utils.stringutils.to_unicode(msg),
             )
         return msg
 
