@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 import functools
 import logging
 import os
@@ -8,7 +7,6 @@ import textwrap
 
 import pytest
 import salt.version
-import six
 
 log = logging.getLogger(__name__)
 
@@ -33,16 +31,13 @@ class Tempfiles:
         """
         tfile = tempfile.NamedTemporaryFile("w", prefix=prefix or "tmp", suffix=".py", delete=False)
         contents = textwrap.dedent(contents.lstrip("\n")).strip()
-        if six.PY2:
-            # We need to write bytestrings, str in Py2
-            contents = contents.encode(__salt_system_encoding__)
         tfile.write(contents)
         tfile.close()
         if executable is True:
             st = os.stat(tfile.name)
             os.chmod(tfile.name, st.st_mode | stat.S_IEXEC)
         self.request.addfinalizer(functools.partial(self._delete_temp_file, tfile.name))
-        with open(tfile.name, "r") as rfh:
+        with open(tfile.name) as rfh:
             log.debug(
                 "Created python file with contents:\n>>>>> %s >>>>>\n%s\n<<<<< %s <<<<<\n",
                 tfile.name,
@@ -60,12 +55,9 @@ class Tempfiles:
             name = tfile.name
         with open(name, "w") as wfh:
             contents = textwrap.dedent(contents.lstrip("\n")).strip()
-            if six.PY2:
-                # We need to write bytestrings, str in Py2
-                contents = contents.encode(__salt_system_encoding__)
             wfh.write(contents)
         self.request.addfinalizer(functools.partial(self._delete_temp_file, name))
-        with open(name, "r") as rfh:
+        with open(name) as rfh:
             log.debug(
                 "Created SLS file with contents:\n>>>>> %s >>>>>\n%s\n<<<<< %s <<<<<\n",
                 name,
