@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     tests.functional.markers.test_requires_network
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -6,8 +5,8 @@
     Test the ``@pytest.mark.requires_network`` marker
 """
 import socket
+from unittest import mock
 
-import mock
 import pytest
 
 from saltfactories.utils import ports
@@ -27,7 +26,7 @@ def test_has_local_network(testdir):
     res.assert_outcomes(passed=1)
     try:
         res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:
+    except AttributeError:  # pragma: no cover
         # PyTest 4.6.x
         from _pytest.outcomes import Failed
 
@@ -58,7 +57,7 @@ def test_no_local_network(testdir):
             res.assert_outcomes(skipped=1)
     try:
         res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:
+    except AttributeError:  # pragma: no cover
         # PyTest 4.6.x
         from _pytest.outcomes import Failed
 
