@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     tests.functional.markers.test_skip_if_not_root
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -6,8 +5,8 @@
     Test the ``@pytest.mark.skip_if_not_root`` marker
 """
 import sys
+from unittest import mock
 
-import mock
 import pytest
 
 
@@ -31,7 +30,7 @@ def test_skip_if_not_root_skipped(testdir):
         res.assert_outcomes(skipped=1)
     try:
         res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:
+    except AttributeError:  # pragma: no cover
         # PyTest 4.6.x
         from _pytest.outcomes import Failed
 
@@ -61,7 +60,7 @@ def test_skip_if_not_root_not_skipped(testdir):
         res.assert_outcomes(passed=1)
     try:
         res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:
+    except AttributeError:  # pragma: no cover
         # PyTest 4.6.x
         from _pytest.outcomes import Failed
 
