@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
 """
     tests.functional.markers.test_skip_on_platforms
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     Test the ``@pytest.mark.skip_on_platforms`` marker
 """
-import mock
+from unittest import mock
+
 import pytest
 
 
@@ -33,7 +33,7 @@ def test_skipped(testdir, platform):
         res.assert_outcomes(skipped=1)
     try:
         res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:
+    except AttributeError:  # pragma: no cover
         # PyTest 4.6.x
         from _pytest.outcomes import Failed
 
@@ -67,7 +67,7 @@ def test_not_skipped(testdir, platform):
         res.assert_outcomes(passed=1)
     try:
         res.stdout.no_fnmatch_line("*PytestUnknownMarkWarning*")
-    except AttributeError:
+    except AttributeError:  # pragma: no cover
         # PyTest 4.6.x
         from _pytest.outcomes import Failed
 
