@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     tests.functional.test_sys_stats
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -54,23 +53,10 @@ def test_proc_sys_stats(testdir):
     p = testdir.makepyfile(
         """
         import pytest
-        import shutil
-
-        from saltfactories.utils.processes.sshd import SshdDaemon
-
 
         @pytest.fixture(scope="module")
-        def sshd_config_dir(salt_factories):
-            config_dir = salt_factories.root_dir.join("sshd").ensure(dir=True)
-            yield config_dir.strpath
-            shutil.rmtree(config_dir.strpath, ignore_errors=True)
-
-
-        @pytest.fixture(scope="module")
-        def sshd(request, sshd_config_dir, salt_factories):
-            return salt_factories.spawn_daemon(
-                request, "sshd", SshdDaemon, "test-sshd", config_dir=sshd_config_dir, cwd=sshd_config_dir
-            )
+        def sshd(request, salt_factories):
+            return salt_factories.spawn_sshd_server(request, "sshd")
 
         def test_one(sshd):
             assert sshd.is_alive()
