@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     tests.unit.utils.processes.salts.test_salt_script_base
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -8,8 +7,8 @@
 import json
 import sys
 from collections import OrderedDict
+from unittest import mock
 
-import mock
 import pytest
 
 from saltfactories.utils.processes.bases import ProcessResult
