@@ -1,11 +1,10 @@
-# -*- coding: utf-8 -*-
 """
     tests.unit.utils.test_platforms
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     Tests for saltfactories.utils.platforms
 """
-import mock
+from unittest import mock
 
 import saltfactories.utils.platform
 
